@@ -30,8 +30,18 @@ class CookieRedirectingFormPlugin(object):
         form key that will be checked for username value [#f1]_
     :param password_field:
         form key that will be checked for password value [#f1]_
-    :type force_https:
-        boolean
+    :param force_https:
+        only allow https for exchanging data
+    :param encoding:
+        encoding to use for managing strings
+    :param fail_redirect_path:
+        if authentications fails, redirect to this path (common usage: '/?message=wrong_login')
+    :type force_https: boolean
+
+    :versionadded: 0.3.0
+
+        `encoding` and `fail_redirect_path` parameters
+        
     """
 
     implements(IChallenger, IIdentifier)
@@ -46,17 +56,13 @@ class CookieRedirectingFormPlugin(object):
             login_redirect_method='cookie',
             username_field='login',
             password_field='password',
-            force_https=False):
-        self.login_form_path = login_form_path
-        self.login_handler_path = login_handler_path
-        self.logout_handler_path = logout_handler_path
-        self.rememberer_name = rememberer_name
-        self.force_https = force_https
-        self.login_redirect_method = login_redirect_method
-        self.logout_redirect_method = logout_redirect_method
-        self.default_redirect_path = default_redirect_path
-        self.username_field = username_field
-        self.password_field = password_field
+            force_https=False,
+            encoding='utf-8',
+            fail_redirect_path=None):
+        if fail_redirect_path is None:
+            fail_redirect_path = login_form_path
+        for key, value in locals().iteritems():
+            setattr(self, key, value)
 
     def _extract_came_from(self, environ, use_current=False):
         """
@@ -127,14 +133,14 @@ class CookieRedirectingFormPlugin(object):
 
             try:
                 credentials = {
-                    'login': unicode(form[self.username_field], 'utf-8'),
-                    'password': unicode(form[self.password_field], 'utf-8')
+                    'login': unicode(form[self.username_field], self.encoding),
+                    'password': unicode(form[self.password_field], self.encoding)
                 }
             except KeyError:
                 log and log.debug('login failed: both login '
                         'and password form inputs must be given')
                 environ['repoze.who.application'] = \
-                    HTTPFound(self.login_form_path)
+                    HTTPFound(self.fail_redirect_path)
                 return
 
             # get cookies and search for 'came_from'
@@ -202,6 +208,8 @@ def make_redirecting_plugin(login_form_path=None,
                             username_field='login',
                             password_field='password',
                             force_https=False,
+                            encoding='utf-8',
+                            fail_redirect_path=None,
                             **kw):
     """
     Function helper for plugin generation from .ini files.
@@ -229,7 +237,7 @@ def make_redirecting_plugin(login_form_path=None,
 
     if login_form_path is None:
         raise ValueError(
-            'login_form_url must be set in configuration')
+            'login_form_path must be set in configuration')
     if login_handler_path is None:
         raise ValueError(
             'login_handler_path must not be None')
@@ -254,6 +262,8 @@ def make_redirecting_plugin(login_form_path=None,
                                    username_field,
                                    password_field,
                                    force_https,
+                                   encoding,
+                                   fail_redirect_path,
                                    **kw)
 
 def asbool(obj):
